@@ -32,6 +32,8 @@ pub enum Instrument {
     M20RearHazRight,
     M20Watson,
     M20SuperCam,
+    M20HeliNav,
+    M20HeliRte,
     NsytICC,
     NsytIDC,
     None
@@ -64,4 +66,12 @@ impl ImageMode {
             ImageMode::U16BIT => 65535.0
         }
     }
+}
+
+
+#[derive(Debug, Copy, Clone, PartialEq)]
+pub enum Axis {
+    XAxis,
+    YAxis,
+    ZAxis
 }
\ No newline at end of file
