@@ -25,4 +25,6 @@ pub mod httpfetch;
 pub mod jsonfetch;
 pub mod time;
 pub mod cahvor;
-pub mod vector;
\ No newline at end of file
+pub mod vector;
+pub mod metadata;
+pub mod matrix;
\ No newline at end of file
