@@ -2,12 +2,14 @@ use crate::{
     vprintln, 
     rgbimage, 
     enums, 
-    path
+    path,
+    constants,
+    util,
+    decompanding
 };
 
-pub fn process_file(input_file:&str, red_scalar:f32, green_scalar:f32, blue_scalar:f32, _no_ilt:bool, only_new:bool) {
-    let out_file = input_file.replace(".jpg", "-rjcal.png").replace(".JPG", "-rjcal.png")
-                             .replace(".png", "-rjcal.png").replace(".PNG", "-rjcal.png");
+pub fn process_file(input_file:&str, red_scalar:f32, green_scalar:f32, blue_scalar:f32, no_ilt:bool, only_new:bool) {
+    let out_file = util::append_file_name(input_file, constants::OUTPUT_FILENAME_APPEND);
     if path::file_exists(&out_file) && only_new {
         vprintln!("Output file exists, skipping. ({})", out_file);
         return;
@@ -18,16 +20,21 @@ pub fn process_file(input_file:&str, red_scalar:f32, green_scalar:f32, blue_scal
     vprintln!("Inpainting...");
     raw.apply_inpaint_fix().unwrap();
 
-    let data_max = 255.0;
+    let mut data_max = 255.0;
 
-    //if ! no_ilt {
-    //    vprintln!("Decompanding...");
-    //    raw.decompand().unwrap();
-    //    data_max = decompanding::get_max_for_instrument(enums::Instrument::M20Watson) as f32;
-    //}
+    if ! no_ilt {
+       vprintln!("Decompanding...");
+       raw.decompand().unwrap();
+       data_max = decompanding::get_max_for_instrument(enums::Instrument::M20Watson) as f32;
+    }
 
     //vprintln!("Flatfielding...");
     //raw.flatfield().unwrap();
+    
+    if input_file.find("ECM") != None && raw.is_grayscale() {
+        vprintln!("Image appears to be grayscale, applying debayering...");
+        raw.debayer().unwrap();
+    }
 
     vprintln!("Applying color weights...");
     raw.apply_weight(red_scalar, green_scalar, blue_scalar).unwrap();
